Crate matrix_kit
matrix_
kit
0.2.36
All Items
Crate Items
Modules
Macros
Crate
matrix_
kit
Modules

dynamic
Macros

compatible_
vectors
index
Translates a row-column coordinate to a flat index in the one dimensional array, indexing along columns. (So, columns are stored next to each other in memory instead of rows)